# evasif

[![PyPI - Version](https://img.shields.io/pypi/v/evasif.svg)](https://pypi.org/project/evasif)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/evasif.svg)](https://pypi.org/project/evasif)

Exploratory video analysis---sea ice fracture

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)


## Installation

```console
python -m pip install evasif
```

## Licence

`evasif` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) licence.


## Acknowledgments

Thanks to Laetitia Drumare for naming this package.
